punctuation.hpp

The punctuation.hpp includes the headers in the punctuation folder.

#### Usage

#include <boost/preprocessor/punctuation.hpp>

#### Includes

- <boost/preprocessor/punctuation/comma.hpp>
- <boost/preprocessor/punctuation/comma_if.hpp>
- <boost/preprocessor/punctuation/paren.hpp>
- <boost/preprocessor/punctuation/paren_if.hpp>

© Copyright Housemarque Oy 2002 © Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)